<?php
/**
 * Zikula Application Framework
 *
 * @copyright (c) 2009, Pawel Preneta <jusuff@jabster.pl>
 * @link http://code.zikula.org/bianor/
 * @version $Id: blank.php 200 2009-12-28 12:02:54Z jusuff $
 * @license GNU/GPL - http://www.gnu.org/copyleft/gpl.html
 * @package menutree
 */

/**
 * "Blank", sample plugin
 *
 * @param array $args['item'] menu node to be replaced
 * @param string $args['lang'] current menu language
 * @param string $args['extrainfo'] additional params - if 'flat' then return links ungrouped
 * @return mixed array of links if successful, false otherwise
 */
function menutree_externalapi_blank($args)
{
    /**
     * args may look like this:
     * Array
     * (
     *     [item] => Array
     *         (
     *             [id] => 999
     *             [name] => Name given in menutree form
     *             [href] => {menutree:ext:blank:foo=1&bar=2}
     *             [title] => Some title
     *             [className] => important
     *             [state] => 1
     *             [lang] => eng
     *             [lineno] => 99
     *             [parent] => 0
     *         )

     *     [lang] => pol
     *     [bid] => 999
     *     [extrainfo] => foo=1&bar=2
     * )
     *
     */
    $dom = ZLanguage::getModuleDomain('menutree');
    $item       = isset($args['item']) && !empty($args['item']) ? $args['item'] : null;
    $lang       = isset($args['lang']) && !empty($args['lang']) ? $args['lang'] : null;
    $bid        = isset($args['bid']) && !empty($args['bid']) ? $args['bid'] : null;
    $extrainfo  = isset($args['extrainfo']) && !empty($args['extrainfo']) ? $args['extrainfo'] : null;

    // $item ang lang params are required
    if(!$item || !$lang) {
        return false;
    }
    // is there is extrainfo - convert it into array, parse_str is quite handy
    if($extrainfo) {
        parse_str($extrainfo, $extrainfo);
    }

    // get id for first element, use api func to aviod id conflicts inside menu
    $idoffset = pnModAPIFunc('menutree','user','getidoffset',array('item' => $item['id']));

    // load plugin language file
    pnModLangLoad('menutree','externalapi_blank');

    $links = array();
    // build some link
    // you may use associative array keys
    $links['first'] = array(
        $lang => array(
            'id' => $idoffset++, // always use id returned by api func for first element
            'name' => $item['name'], // you may use name given by user - but do not have to
            'href' => pnModUrl('News'),
            'title' => $item['title'], // the same as for name - you may use user input
            'className' => $item['className'],
            'state' => $item['state'],
            'lang' => $lang,
            'lineno' => $item['lineno'],
            'parent' => $item['parent'] // always use replaced item parent for element at first level
        )
    );

    // build second link - this one will be child of the first element
    $secondLink = isset($extrainfo['foo']) ? pnModUrl('News','user','display',array('sid' => $extrainfo['foo'])) : pnModUrl('News');
    $links['second'] = array(
        $lang => array(
            'id' => $idoffset++, // using this syntax you're always will have proper ids
            'name' => 'Second blank link',
            'href' => $secondLink,
            'title' => __('Title', $dom), // you may also use translated content
            'className' => '',
            'state' => 1, // for child nodes set state = 1
            'lang' => $lang,
            'lineno' => 0,
            'parent' => $links['first'][$lang]['id'] // use first element id while we want to set this node as child node
        )
    );

    // build third link - this one will be on the same level as first link
    $thirdLink = isset($extrainfo['bar']) ? pnModUrl('News','user','display',array('sid' => $extrainfo['bar'])) : pnModUrl('News');
    $links['third'] = array(
        $lang => array(
            'id' => $idoffset++,
            'name' => 'Third blank link',
            'href' => $thirdLink,
            'title' => '',
            'className' => '',
            'state' => $item['state'], // always use replaced item state for element at first level
            'lang' => $lang,
            'lineno' => $item['lineno']+1,
            'parent' => $item['parent'] // always use replaced item parent for element at first level
        )
    );

    return $links;
}
