<?php
/**
 * Zikula Application Framework
 *
 * @copyright (c) 2009, Pawel Preneta <jusuff@jabster.pl>
 * @link http://code.zikula.org/bianor/
 * @version $Id: news.php 193 2009-12-19 03:29:34Z drak $
 * @license GNU/GPL - http://www.gnu.org/copyleft/gpl.html
 * @package menutree
 */

/**
 * Return some useful News links
 *
 * Syntax used in menutree
 * {menutree:ext:news[:flat=BOOL&links=view,add,cat,arch|ALL]}
 * Params in [] are optional and
 *      flat - true or false, if set to true links are ungrouped (default is false)
 *      links - list of elements, default is ALL, avaiable items:
 *          - view - link to main News view
 *          - add - link do Submit News form
 *          - cat - list of News categories
 *          - arch - link to News archive
 *          Items are displayed in order provided in menutree
 *
 * @param array $args['item'] menu node to be replaced
 * @param string $args['lang'] current menu language
 * @param string $args['extrainfo'] additional params
 * @return mixed array of links if successful, false otherwise
 */
function menutree_externalapi_news($args)
{
    $dom = ZLanguage::getModuleDomain('menutree');
    $item       = isset($args['item']) && !empty($args['item']) ? $args['item'] : null;
    $lang       = isset($args['lang']) && !empty($args['lang']) ? $args['lang'] : null;
    $bid        = isset($args['bid']) && !empty($args['bid']) ? $args['bid'] : null;
    $extrainfo  = isset($args['extrainfo']) && !empty($args['extrainfo']) ? $args['extrainfo'] : null;

    // $item ang lang params are required
    if(!$item || !$lang) {
        return false;
    }
    // is there is extrainfo - convert it into array, parse_str is quite handy
    if($extrainfo) {
        parse_str($extrainfo, $extrainfo);
    }
    $extrainfo['flat'] = isset($extrainfo['flat'])? (bool)$extrainfo['flat'] : false;
    $extrainfo['links'] = isset($extrainfo['links'])? explode(',',$extrainfo['links']) : array('all');

    // get id for first element, use api func to aviod id conflicts inside menu
    $idoffset = pnModAPIFunc('menutree','user','getidoffset',array('item' => $item['id']));
    $lineno = 0;

    // load plugin language file
    $modinfo = pnModGetInfo(pnModGetIDFromName('News'));

    $links = array();
    // build some link
    // you may use associative array keys
    if(!$extrainfo['flat']) {
        $links['news'] = array(
            $lang => array(
                'id' => $idoffset++,
                'name' => $item['name'],
                'href' => pnModURL('News'),
                'title' => $item['title'],
                'className' => $item['className'],
                'state' => $item['state'],
                'lang' => $lang,
                'lineno' => $lineno++,
                'parent' => $item['parent']
            )
        );
    }
    $parentNode = !$extrainfo['flat'] ? $links['news'][$lang]['id'] : $item['parent'];

    if(in_array('all',$extrainfo['links']) || in_array('view',$extrainfo['links'])) {
        $links['view'] = array(
            $lang => array(
                'id' => $idoffset++,
                'name' => $modinfo['displayname'],
                'href' => pnModURL('News'),
                'title' => __('View news', $dom),
                'className' => '',
                'state' => 1,
                'lang' => $lang,
                'lineno' => $lineno++,
                'parent' => $parentNode
            )
        );
    }
    if(in_array('all',$extrainfo['links']) || in_array('arch',$extrainfo['links'])) {
        $links['arch'] = array(
            $lang => array(
                'id' => $idoffset++,
                'name' => __('Archive', $dom),
                'href' => pnModURL('News','user','archives'),
                'title' => __('Archive', $dom),
                'className' => '',
                'state' => 1,
                'lang' => $lang,
                'lineno' => $lineno++,
                'parent' => $parentNode
            )
        );
    }
    if(in_array('all',$extrainfo['links']) || in_array('add',$extrainfo['links'])) {
        $links['add'] = array(
            $lang => array(
                'id' => $idoffset++,
                'name' => __('Submit news', $dom),
                'href' => pnModURL('News','user','new'),
                'title' => __('Submit news', $dom),
                'className' => '',
                'state' => 1,
                'lang' => $lang,
                'lineno' => $lineno++,
                'parent' => $parentNode
            )
        );
    }
    if(in_array('all',$extrainfo['links']) || in_array('cat',$extrainfo['links'])) {
        if(!$extrainfo['flat']) {
            $links['cat'] = array(
                $lang => array(
                    'id' => $idoffset++,
                    'name' => __('Categories', $dom),
                    'href' => pnModURL('News'),
                    'title' => __('Categories', $dom),
                    'className' => '',
                    'state' => 1,
                    'lang' => $lang,
                    'lineno' => $lineno++,
                    'parent' => $parentNode
                )
            );
        }
        $catParentNode = !$extrainfo['flat'] ? $links['cat'][$lang]['id'] : $item['parent'];

        Loader::loadClass('CategoryRegistryUtil');
        Loader::loadClass('CategoryUtil');

        $catregistry  = CategoryRegistryUtil::getRegisteredModuleCategories ('News', 'stories');
        if(!empty($catregistry)) {
            $multicategory = count($catregistry) > 1;
            $catLinks = array();
            foreach($catregistry as $prop => $catid) {
                if($multicategory && !$extrainfo['flat']) {
                    $parentCategory = CategoryUtil::getCategoryByID ($catid);
                    $catLinks[$catid] =  array(
                        $lang => array(
                            'id' => $idoffset++,
                            'name' => isset($parentCategory['display_name'][$lang]) && !empty($parentCategory['display_name'][$lang]) ? $parentCategory['display_name'][$lang] : $parentCategory['name'],
                            'href' => '',
                            'title' => isset($parentCategory['display_name'][$lang]) && !empty($parentCategory['display_name'][$lang]) ? $parentCategory['display_name'][$lang] : $parentCategory['name'],
                            'className' => '',
                            'state' => 1,
                            'lang' => $lang,
                            'lineno' => $lineno++,
                            'parent' => $catParentNode
                        )
                    );
                }
                $categories = CategoryUtil::getSubCategories($catid);
                foreach($categories as $cat) {
                    $catLinks[$cat['id']] = array(
                        $lang => array(
                            'id' => $idoffset++,
                            'name' => isset($cat['display_name'][$lang]) && !empty($cat['display_name'][$lang]) ? $cat['display_name'][$lang] : $cat['name'],
                            'href' => pnModURL('News','user','view',array('prop' => $prop, 'cat' => $cat['name'])),
                            'title' => isset($cat['display_name'][$lang]) && !empty($cat['display_name'][$lang]) ? $cat['display_name'][$lang] : $cat['name'],
                            'className' => '',
                            'state' => 1,
                            'lang' => $lang,
                            'lineno' => $lineno++,
                            'parent' => isset($catLinks[$cat['parent_id']]) ? $catLinks[$cat['parent_id']][$lang]['id'] : $catParentNode
                        )
                    );
                }
            }
        } elseif(!$extrainfo['flat']) {
            unset($links['cat']);
        }
    }

    // sort links in order provided in menutree
    if(!in_array('all',$extrainfo['links'])) {
        $sortedLinks = array();
        if(!$extrainfo['flat']) {
            $sortedLinks[] = $links['news'];
        }
        foreach($extrainfo['links'] as $l) {
            if(isset($links[$l]) && !empty($links[$l])) {
                $sortedLinks[] = $links[$l];
            }
            if($l == 'cat') {
                $sortedLinks = array_merge((array)$sortedLinks, (array)$catLinks);
            }
        }
        $links = $sortedLinks;
    }

    return $links;
}
