<?php
/**
 * Zikula Application Framework
 *
 * @copyright (c) 2009, Pawel Preneta <jusuff@jabster.pl>
 * @link http://code.zikula.org/bianor/
 * @version $Id: userlinks.php 193 2009-12-19 03:29:34Z drak $
 * @license GNU/GPL - http://www.gnu.org/copyleft/gpl.html
 * @package menutree
 */

/**
 * Return some common user links
 *
 * Syntax used in menutree
 * {menutree:ext:userlinks[:flat]}
 * Last param is optional
 *
 * This plugin generates a list of  some common user links. The list looks as follows:
 * for loggedin users:
 *      Your Account
 *          Profile
 *          Private Messages (if there is some message module)
 *          Logout
 * for anonymous users:
 *      Your Account
 *          Login
 *          Register
 *          Lost Password
 *
 * If you provide an additional param extrainfo = flat, then the links are not grouped within
 * Your Accont element
 *
 * @param array $args['item'] menu node to be replaced
 * @param string $args['lang'] current menu language
 * @param string $args['extrainfo'] additional params - if 'flat' then return links ungrouped
 * @return mixed array of links if successful, false otherwise
 */
function menutree_externalapi_userlinks($args)
{
    $dom = ZLanguage::getModuleDomain('menutree');
    $item       = isset($args['item']) && !empty($args['item']) ? $args['item'] : null;
    $lang       = isset($args['lang']) && !empty($args['lang']) ? $args['lang'] : null;
    $extrainfo  = isset($args['extrainfo']) && !empty($args['extrainfo']) ? $args['extrainfo'] : null;
    // $item ang lang params are required
    if(!$item || !$lang) {
        return false;
    }

    // get id for first element, use api func to aviod id conflicts inside menu
    $idoffset = pnModAPIFunc('menutree','user','getidoffset',array('item' => $item['id']));
    $lineno = 0;

    // module config
    $profileModule = pnConfigGetVar('profilemodule') ? pnConfigGetVar('profilemodule') : 'Profile';
    $profileModule = pnModAvailable($profileModule) ? $profileModule : null;

    $messageModule = pnConfigGetVar('messagemodule') ? pnConfigGetVar('messagemodule') : 'InterCom';
    $messageModule = pnModAvailable($messageModule) ? $messageModule : null;

    $links = array();
    // if $extrainfo if 'flat' - don't group links in your_account node
    if($extrainfo != 'flat') {
        $links['your_account'] = array(
            $lang => array(
                'id' => $idoffset++,
                'name' => $item['name'],
                'href' => pnModUrl($profileModule),
                'title' => $item['title'],
                'className' => $item['className'],
                'state' => $item['state'],
                'lang' => $lang,
                'lineno' => $lineno++,
                'parent' => $item['parent']
            )
        );
    }
    // need to set parent node id - if links are grouped - use your_accont item id
    // otherwise parent id of replaced menu node
    $parentNode = $extrainfo != 'flat' ? $links['your_account'][$lang]['id'] : $item['parent'];

    if(pnUserLoggedIn()) {
        $links['profile'] = array(
            $lang => array(
                'id' => $idoffset++,
                'name' => __('Profile', $dom),
                'href' => pnModUrl($profileModule),
                'title' => __('Profile', $dom),
                'className' => '',
                'state' => 1,
                'lang' => $lang,
                'lineno' => $lineno++,
                'parent' => $parentNode
            )
        );
        if(!is_null($messageModule)) {
            $links['messages'] = array(
                $lang => array(
                    'id' => $idoffset++,
                    'name' => __('Private messages', $dom),
                    'href' => pnModUrl($messageModule),
                    'title' => __('Private messages', $dom),
                    'className' => '',
                    'state' => 1,
                    'lang' => $lang,
                    'lineno' => $lineno++,
                    'parent' => $parentNode
                )
            );
        }
        $links['logout'] = array(
            $lang => array(
                'id' => $idoffset++,
                'name' => __('Logout', $dom),
                'href' => pnModUrl('Users','user','logout'),
                'title' => __('Logout', $dom),
                'className' => '',
                'state' => 1,
                'lang' => $lang,
                'lineno' => $lineno++,
                'parent' => $parentNode
            )
        );
    } else {
        $links['login'] = array(
            $lang => array(
                'id' => $idoffset++,
                'name' => __('Login', $dom),
                'href' => pnModUrl('Users','user','loginscreen'),
                'title' =>__('Login', $dom),
                'className' => '',
                'state' => 1,
                'lang' => $lang,
                'lineno' => $lineno++,
                'parent' => $parentNode
            )
        );
        $links['register'] = array(
            $lang => array(
                'id' => $idoffset++,
                'name' => __('Register', $dom),
                'href' => pnModUrl('Users','user','register'),
                'title' => __('Register', $dom),
                'className' => '',
                'state' => 1,
                'lang' => $lang,
                'lineno' => $lineno++,
                'parent' => $parentNode
            )
        );
        $links['lostpassword'] = array(
            $lang => array(
                'id' => $idoffset++,
                'name' => __('Lost password', $dom),
                'href' => pnModUrl('Users','user','lostpassword'),
                'title' => __('Lost password', $dom),
                'className' => '',
                'state' => 1,
                'lang' => $lang,
                'lineno' => $lineno++,
                'parent' => $parentNode
            )
        );
    }

    return $links;
}
